function y = mttflipdimsall(x)
%MTTFLIPDIMSALL Flip array along all dimensions.
%
%   MTTFLIPDIMSALL(X) flips the array X along all dimension.
%
%   See also MTTFLIPDIM.

%   This program is a part of the MTT (MATLAB Tips & Tricks) Toolbox.
%   Copyright (c) 2002 Peter J. Acklam. All rights reserved.
%
%   This program is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.  See the file COPYING for details.
%
%   Author:      Peter J. Acklam
%   Time-stamp:  2003-03-31 18:32:11 +0200
%   E-mail:      pjacklam@online.no
%   URL:         http://home.online.no/~pjacklam

   % check number of input arguments
   error(nargchk(1, 1, nargin));

   % quick exit if input is empty
   if isempty(x)
      y = x;
      return;
   end

   % get size of X and find non-singleton dimensions
   sx   = size(x);
   dims = find(sx > 1);

   % initialize subscript cell array
   idx{ndims(x)} = ':';
   idx(:) = idx(end);

   % flip along all non-singleton dimensions (flipping along singleton
   % dimensions is a null-operation)
   for i = 1:length(dims)
      dim = dims(i);
      idx{dim} = sx(dim):-1:1;
   end

   y = x(idx{:});
