function tf = mttnumlexcmp(a, b)
%MTTNUMLEXCMP Lexicographic comparison of two numbers.
%
%   MTTNUMLEXCMP(A, B) returns -1, 0, or 1 depending on whether the left
%   argument is lexicographically less than, equal to, or greater than the
%   right argument.
%
%   When A and B are complex, the real parts of the elements are compared.
%   If the real parts are identical, the imaginary parts are compared.
%
%   This is a MATLAB version of the Perl `<=>' operator.

%   This program is a part of the MTT (MATLAB Tips & Tricks) Toolbox.
%   Copyright (c) 2002 Peter J. Acklam. All rights reserved.
%
%   This program is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.  See the file COPYING for details.
%
%   Author:      Peter J. Acklam
%   Time-stamp:  2003-03-31 18:31:29 +0200
%   E-mail:      pjacklam@online.no
%   URL:         http://home.online.no/~pjacklam

   % check number of input arguments
   error(nargchk(2, 2, nargin));

   % check input arguments
   if ~isnumeric(a) | ~isnumeric(b)
      error('Both arguments must be numerical arrays.');
   end

   % Comparison is done with (x < y) - (x > y).  We could have used
   % sign(x - y), but both `-' and `sign' are, by default, only defined for
   % numerical arrays of class double.

   % compare real parts
   tf = (real(a) < real(b)) - (real(a) > real(b));

   % compare imaginary parts if necessary
   if ~isreal(a) | ~isreal(b)
      k = ~tf;
      if any(k(:))
         tf(k) = (imag(a(k)) < imag(b(k))) - (imag(a(k)) > imag(b(k)));
      end
   end
