function x = mttrldecode(len, val)
%MTTRLDECODE Run-length decoding of run-length encode data.
%
%   X = MTTRLDECODE(LEN, VAL) returns a vector XLEN with the length of each
%   run and a vector VAL with the corresponding values.  LEN and VAL must
%   have the same lengths.
%
%   Example: mttrldecode([ 2 3 1 2 4 ], [ 6 4 5 8 7 ]) will return
%
%      x = [ 6 6 4 4 4 5 8 8 7 7 7 7 ];
%
%   See also MTTRLENCODE.

%   This program is a part of the MTT (MATLAB Tips & Tricks) Toolbox.
%   Copyright (c) 2002 Peter J. Acklam. All rights reserved.
%
%   This program is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.  See the file COPYING for details.
%
%   Author:      Peter J. Acklam
%   Time-stamp:  2003-03-31 18:31:09 +0200
%   E-mail:      pjacklam@online.no
%   URL:         http://home.online.no/~pjacklam

   % keep only runs whose length is positive
   k = len > 0;
   len = len(k);
   val = val(k);

   % now perform the actual run-length decoding
   i = cumsum(len);             % LENGTH(LEN) flops
   j = zeros(1, i(end));
   j(i(1:end-1)+1) = 1;         % LENGTH(LEN) flops
   j(1) = 1;
   x = val(cumsum(j));          % SUM(LEN) flops
